# GoldenViz

do you know the golden rules of a successful data vizulisation? this library helps users to ensure their data viz communicate the information as clearly and neutrally as possible, while respecting a set of Golden Rules.

This is the init version of the repo, development will be structured and enrich on the upcoming weeks.

Will include the first beta version, with proper documentation.